Index: /issm/trunk-jpl/test/NightlyRun/test234.m
===================================================================
--- /issm/trunk-jpl/test/NightlyRun/test234.m	(revision 14269)
+++ /issm/trunk-jpl/test/NightlyRun/test234.m	(revision 14270)
@@ -62,14 +62,14 @@
 
 %Fields and tolerances to track changes
-md.results.dakota.importancefactors=[];
+md.results.dakota.moments=[];
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).mean];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).mean];
 end
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).stddev];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).stddev];
 end
-field_names     ={'importancefactors'};
+field_names     ={'moments'};
 field_tolerances={1e-11};
 field_values={...
-         md.results.dakota.importancefactors,...
+         md.results.dakota.moments,...
 	};
Index: /issm/trunk-jpl/test/NightlyRun/test235.m
===================================================================
--- /issm/trunk-jpl/test/NightlyRun/test235.m	(revision 14269)
+++ /issm/trunk-jpl/test/NightlyRun/test235.m	(revision 14270)
@@ -59,14 +59,14 @@
 
 %Fields and tolerances to track changes
-md.results.dakota.importancefactors=[];
+md.results.dakota.moments=[];
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).mean];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).mean];
 end
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).stddev];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).stddev];
 end
-field_names     ={'importancefactors'};
+field_names     ={'moments'};
 field_tolerances={1e-11};
 field_values={...
-         md.results.dakota.importancefactors,...
+         md.results.dakota.moments,...
 	};
Index: /issm/trunk-jpl/test/NightlyRun/test414.m
===================================================================
--- /issm/trunk-jpl/test/NightlyRun/test414.m	(revision 14269)
+++ /issm/trunk-jpl/test/NightlyRun/test414.m	(revision 14270)
@@ -55,16 +55,16 @@
 %we recover those mass fluxes through the mean of the response.
 %also, we recover the max velo, which should be 1m/yr. 
 %we put all that data in the importancefactors, which we will use to test for success.
 %also, check that the stddev are 0.
-md.results.dakota.importancefactors=[];
+md.results.dakota.moments=[];
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).mean];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).mean];
 end
 for i=1:8,
-	md.results.dakota.importancefactors=[md.results.dakota.importancefactors md.results.dakota.dresp_out(i).stddev];
+	md.results.dakota.moments=[md.results.dakota.moments md.results.dakota.dresp_out(i).stddev];
 end
-field_names     ={'importancefactors'};
+field_names     ={'moments'};
 field_tolerances={1e-11};
 field_values={...
-         md.results.dakota.importancefactors,...
+         md.results.dakota.moments,...
 	};
@@ -55,16 +55,16 @@
 %we recover those mass fluxes through the mean of the response.
 %also, we recover the max velo, which should be 1m/yr. 
-%we put all that data in the importancefactors, which we will use to test for success.
+%we put all that data in the moments, which we will use to test for success.
 %also, check that the stddev are 0.
